.. include:: /substitutions.txt

.. _user_guide:

==========
User Guide
==========

Guidance is provided in various sections, from project overview, to usability,
and all the nitty-gritty details.

.. toctree::
   :glob:
   :hidden:

   overview
   ready_to_use
   examples/*
   constraints

.. grid:: 1

    .. grid-item::

        .. grid:: 3

            .. grid-item-card:: :ref:`overview`
            .. grid-item-card:: :ref:`install`
            .. grid-item-card:: :ref:`api_documentation`

    .. grid-item:: User interface

        .. grid:: 2

            .. grid-item-card:: :ref:`User Friendliness <user>`
            .. grid-item-card:: :ref:`Export & restore UB <configuration>`
            .. grid-item-card:: :ref:`ready_to_use`
            .. grid-item-card:: :ref:`geometry_tables`
            .. grid-item-card:: :ref:`constraints`
            .. grid-item-card:: :ref:`spec_commands_map`

    .. grid-item:: Examples

        .. grid:: 2

            .. grid-item-card:: :ref:`examples.diffractometer`
            .. grid-item-card:: :ref:`examples.howto`
            .. grid-item-card:: :ref:`examples.variations`
            .. grid-item-card:: :ref:`examples.tests`
